#
# git clone https://github.com/compiz-reloaded/compiz.git
# cd compiz
# DATE=$(git log -1 --format="%cd" --date=short | sed "s|-||g")
# git archive --format=tar --prefix=compiz-${DATE}/ master | xz > ../compiz-${DATE}.tar.xz
#

# comment out if not snapshot
#define gdate	20190717

# rel for bumping
%define rel	2

%define	major	0
%define	libname	%mklibname decoration %major
%define	devname %mklibname decoration -d

# List of plugins passed to ./configure.  The order is important
%global plugins	core,dbus,decoration,fade,minimize,move,obs,place,png,resize,scale,screenshot,svg,switcher,wall

Name:		compiz
Epoch:		1
Version:	0.8.18
Release:	%mkrel %{?gdate:0.git%gdate.}%{rel}
Summary:	OpenGL composite manager for Xgl and AIGLX
Group:		System/X11
URL:		https://github.com/compiz-reloaded/compiz
License:	GPLv2+ and LGPLv2+ and MIT
Source0:	https://github.com/compiz-reloaded/compiz/archive/v%{version}/%{name}-%{?gdate}%{?!gdate:%version}.tar.%{?gdate:xz}%{?!gdate:gz}
Source1:	mageia-top.png
Source10:	compiz.defaults
Source11:	compiz-fusion
Source12:	compiz-fusion.defaults

Patch0:		compiz-mageia-logo.patch

BuildRequires:	gettext-devel
BuildRequires:	intltool
BuildRequires:	xsltproc
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xcomposite)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xfixes)
BuildRequires:	pkgconfig(xdamage)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(xi)
BuildRequires:	pkgconfig(xinerama)
BuildRequires:	pkgconfig(xcursor)
BuildRequires:	pkgconfig(ice)
BuildRequires:	pkgconfig(sm)
BuildRequires:	pkgconfig(libstartup-notification-1.0)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(egl)
BuildRequires:	pkgconfig(dbus-glib-1)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(fuse)
BuildRequires:	pkgconfig(cairo-xlib-xrender)
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(librsvg-2.0)
BuildRequires:	pkgconfig(libmarco-private) >= 1.22.2
BuildRequires:	pkgconfig(libwnck-3.0)

Requires:	compizconfig
Requires:	compiz-ccsm
Requires:	compiz-decorator
Requires:	compositing-wm-common

Conflicts:	compiz-decorator-gtk < 1:0.8.16.1

%description
Compiz is an OpenGL compositing manager, which means that it enhances
the overall user interaction by adding fancy effects to your windows,
from drop shadows to desktop effects like the Desktop Cube or the Expo view.

Compiz can also be a window manager, which means that it is the software
between you and your desktop apps. It enables you to move or resize windows,
to switch workspaces, to switch windows easily (using alt-tab or so), and so on.


%files -f %{name}.lang
%doc AUTHORS NEWS README*
%license COPYING COPYING.GPL COPYING.LGPL COPYING.MIT
%{_bindir}/%{name}
%{_bindir}/%{name}-window-decorator
%{_bindir}/%{name}-decorator
%{_bindir}/%{name}-fusion
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/compositing-wm/%{name}.defaults
%{_datadir}/compositing-wm/%{name}-fusion.defaults
%{_datadir}/applications/compiz-start.desktop
%{_datadir}/applications/compiz.desktop
%{_iconsdir}/hicolor/*/apps/compiz.*

#----------------------------------------------------------------------------

%package decorator-gtk
Summary:	GTK window decorator for compiz
Group:		System/X11

Provides:	compiz-decorator
Requires:	%{name} = %{epoch}:%{version}-%{release}

%description decorator-gtk
This package provides a GTK window decorator for the compiz OpenGL
compositing manager.

%files decorator-gtk
%{_bindir}/gtk-window-decorator
%{_iconsdir}/hicolor/*/apps/gtk-decorator.*
%{_datadir}/glib-2.0/schemas/org.compiz-0.gwd.gschema.xml

#----------------------------------------------------------------------------

%package -n %libname
Summary:	Shared libraries for compiz
Group:		System/X11
Obsoletes:	%{_lib}compiz0 < 0.9.13.1-7

%description -n %libname
This package provides shared libraries for compiz.

%files -n %libname
%{_libdir}/libdecoration.so.%{major}{,.*}

#----------------------------------------------------------------------------

%package -n %devname
Summary:	Development files for compiz
Group:		Development/X11
Provides:	%{name}-devel = %{epoch}:%{version}-%{release}
Requires:	%{libname} = %{epoch}:%{version}-%{release}
Obsoletes:	%{_lib}compiz-devel < 0.9.13.1-7

%description -n %devname
This package provides development files for compiz.

%files -n %devname
%{_includedir}/%{name}/
%{_libdir}/libdecoration.so
%{_libdir}/pkgconfig/compiz-cube.pc
%{_libdir}/pkgconfig/compiz-scale.pc
%{_libdir}/pkgconfig/compiz.pc
%{_libdir}/pkgconfig/libdecoration.pc

#----------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{name}-%{?gdate}%{?!gdate:%version}

# make autoreconf happy
mkdir -p m4

%build
autoreconf -vfi -Im4
intltoolize --force
%configure \
	--disable-rpath \
	--disable-static \
	--with-gtk=3.0 \
	--enable-gtk \
	--enable-librsvg \
	--enable-menu-entries \
	--with-default-plugins=%{plugins}
%make_build

%install
%make_install

# image for cube
install -Dpm644 %{_sourcedir}/mageia-top.png %{buildroot}%{_datadir}/compiz/%{_real_vendor}.png

install -D -m644 %{_sourcedir}/%{name}.defaults %{buildroot}%{_datadir}/compositing-wm/%{name}.defaults
install -m755 %{_sourcedir}/%{name}-fusion %{buildroot}%{_bindir}/%{name}-fusion
install -m644 %{_sourcedir}/%{name}-fusion.defaults %{buildroot}%{_datadir}/compositing-wm/%{name}-fusion.defaults

# we don't want these
find %{buildroot} -name "*.la" -delete

# Compiz now provides a script to choose decorator, so we dropped our own
# make a link to not break existing setup which rely on former script.
ln -s %{_bindir}/%{name}-decorator %{buildroot}/%{_bindir}/%{name}-window-decorator

%find_lang %{name}


%changelog
* Tue Sep 22 2020 kekepower <kekepower> 1:0.8.18-2.mga8
+ Revision: 1629445
- Rebuild for recently updated libraries

* Sat Apr 18 2020 wally <wally> 1:0.8.18-1.mga8
+ Revision: 1568876
- new version 0.8.18

* Sat Feb 15 2020 umeabot <umeabot> 1:0.8.17-0.git20190717.2.mga8
+ Revision: 1527626
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu Jul 18 2019 wally <wally> 1:0.8.17-0.git20190717.1.mga8
+ Revision: 1422596
- update to latest git snapshot to build with latest marco

* Sat Dec 29 2018 luigiwalser <luigiwalser> 1:0.8.16.1-3.mga7
+ Revision: 1346012
- rebuild for protobuf

* Sun Dec 09 2018 wally <wally> 1:0.8.16.1-2.mga7
+ Revision: 1339368
- require compositing-wm-common (instead of compiz-manager)

* Sun Dec 09 2018 wally <wally> 1:0.8.16.1-1.mga7
+ Revision: 1339344
- switch to compiz-reloaded upstream
- new version 0.8.16.1
- new epoch 1

* Sun Sep 23 2018 umeabot <umeabot> 0.9.13.1-6.mga7
+ Revision: 1296745
- Mageia 7 Mass Rebuild

* Sun Apr 15 2018 daviddavid <daviddavid> 0.9.13.1-5.mga7
+ Revision: 1219035
- rebuild for new protobuf 3.5

* Sat Feb 10 2018 daviddavid <daviddavid> 0.9.13.1-4.mga7
+ Revision: 1200059
- fix files list for cmake 3.10+
- fix some owner data and library dir

* Sun Mar 12 2017 neoclust <neoclust> 0.9.13.1-3.mga6
+ Revision: 1092149
- Rebuild on armv7

* Mon Feb 13 2017 neoclust <neoclust> 0.9.13.1-2.mga6
+ Revision: 1085973
- Rebuild for ARM

* Sat Feb 04 2017 tarakbumba <tarakbumba> 0.9.13.1-1.mga6
+ Revision: 1084848
- Update to 0.9.13.1 version

* Mon Jul 11 2016 pterjan <pterjan> 0.9.12.2-4.mga6
+ Revision: 1041196
- Try to fix arm build (it builds for me already without that change :( )

* Mon Mar 21 2016 daviddavid <daviddavid> 0.9.12.2-3.mga6
+ Revision: 993627
- update files list (cmake-3.4 -> cmake-3.?)
- use new python macros

* Sat Feb 20 2016 umeabot <umeabot> 0.9.12.2-2.mga6
+ Revision: 971686
- Mageia 6 Mass Rebuild

* Sat Oct 17 2015 tarakbumba <tarakbumba> 0.9.12.2-1.mga6
+ Revision: 892267
- Update to 0.9.12.2 (mga#16720)
- Disable kde4 support to fix build
- Disable deprecated gconf backend

* Fri Oct 17 2014 luigiwalser <luigiwalser> 0.9.10.0-13.mga5
+ Revision: 778725
- do not fail to compile because of a deprecation warning
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Rebuild to fix library dependencies
- Mageia 5 Mass Rebuild
+ tv <tv>
- rebuild for missing pythoneggs deps
- s/uggests:/Recommends:/

* Mon Sep 01 2014 luigiwalser <luigiwalser> 0.9.10.0-9.mga5
+ Revision: 670362
- add cmake 3.0 path to files
- rebuild for protobuf

* Mon Jul 07 2014 tarakbumba <tarakbumba> 0.9.10.0-7.mga5
+ Revision: 650493
- Add patch from upstream to fix clicking on maximized window buttons (mga#12810)
- Add conflicts tag to libcompiz0 package

* Sat Jul 05 2014 tarakbumba <tarakbumba> 0.9.10.0-6.mga5
+ Revision: 643916
- Move development .so files to devel subpackage
+ pterjan <pterjan>
- Rebuild for new Python

* Wed Jan 01 2014 pterjan <pterjan> 0.9.10.0-4.mga4
+ Revision: 563838
- Rebuild for new protobuf

* Tue Oct 22 2013 umeabot <umeabot> 0.9.10.0-3.mga4
+ Revision: 544896
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.9.10.0-2.mga4
+ Revision: 500474
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Sep 18 2013 julien <julien> 0.9.10.0-1.mga4
+ Revision: 481311
- new version 0.9.10
- rediff patch0

* Tue Jul 09 2013 fwang <fwang> 0.9.9.0-5.mga4
+ Revision: 451717
- rebuild for new boost

* Mon Jun 03 2013 fwang <fwang> 0.9.9.0-4.mga4
+ Revision: 435561
- rebuild for new libpng

* Sat Apr 13 2013 julien <julien> 0.9.9.0-3.mga3
+ Revision: 409875
- add upstream patch to fix build with boost 1.53, thanks to Barry Jackson for digging this

* Tue Mar 26 2013 julien <julien> 0.9.9.0-2.mga3
+ Revision: 405323
- add default path to compositor wrapper MGA#9453

* Thu Jan 24 2013 julien <julien> 0.9.9.0-1.mga3
+ Revision: 392188
- update to v0.9.9.0
- drop patch 601,602,603
- rediff patch0

* Fri Jan 11 2013 umeabot <umeabot> 0.9.8.6-3.mga3
+ Revision: 348101
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 19 2012 julien <julien> 0.9.8.6-2.mga3
+ Revision: 332873
- add patch603 to fix initialization of plugins (MGA#7720)

* Sun Nov 25 2012 julien <julien> 0.9.8.6-1.mga3
+ Revision: 321742
- add upstream patch601 to fix build with new kde
- new version 0.9.8.6

* Sun Nov 18 2012 julien <julien> 0.9.8.4-2.mga3
+ Revision: 319458
- add upstream patch to fix MGA#5626 (black background icon in titlebar)

* Sun Sep 30 2012 julien <julien> 0.9.8.4-1.mga3
+ Revision: 300846
- new version 0.9.8.4

* Thu Sep 13 2012 julien <julien> 0.9.8.2-1.mga3
+ Revision: 293713
- update to 0.9.8.2
- drop merged upstream patches
- reenabling Werror
- disabling the directive BUILD_SHARED_LIBS as it cause strange build failure

* Sun Sep 02 2012 julien <julien> 0.9.8.0-4.mga3
+ Revision: 287381
- fix crash when loading svg plugin (upstream patch)

* Sat Sep 01 2012 julien <julien> 0.9.8.0-3.mga3
+ Revision: 286969
- really obsolete libcompizconfig-devel

* Fri Aug 31 2012 julien <julien> 0.9.8.0-2.mga3
+ Revision: 286773
- reenable kde support (upstream patch, bug lp#1041310)
- add obsoletes for devel package
- correct list of gconf schemas
+ fwang <fwang>
- update url

* Fri Aug 31 2012 fwang <fwang> 0.9.8.0-1.mga3
+ Revision: 285951
- update file list
- more patch
- fix libdir installation
- disable werror
- rebuild for new boost
+ julien <julien>
- drop compiz-plugin-main|extra, merged in compiz
- drop compizconfig-common, merged in compiz
- drop libcompizconfig, merged in libcompiz
- rename ccsm to compiz-ccsm
- drop our own script to choose decorator in favor of upstream one
- drop PATCH502 Use-our-compiz-window-decorator-script-as-the-default
- new version 0.9.8.0
- disable kde support for the time being as it doesn't build

* Wed May 30 2012 fwang <fwang> 0.9.7.8-2.mga3
+ Revision: 249687
- rebuild for new boost

* Thu Apr 26 2012 julien <julien> 0.9.7.8-1.mga2
+ Revision: 233365
- new version 0.9.7.8

* Fri Apr 13 2012 julien <julien> 0.9.7.6-2.mga2
+ Revision: 230724
- add sane default pref for compiz-fusion (not very pretty hack)
  	should fix #5190: decoration not applied when compiz-fusion
  	is started with a fresh profile

* Fri Apr 06 2012 julien <julien> 0.9.7.6-1.mga2
+ Revision: 229375
- new version 0.9.7.6

* Sun Apr 01 2012 julien <julien> 0.9.7.4-1.mga2
+ Revision: 227682
- update to new version 0.9.7.4

* Fri Mar 23 2012 julien <julien> 0.9.7.2-1.mga2
+ Revision: 225824
- update to 0.9.7.2

* Sat Mar 03 2012 julien <julien> 0.9.7.0-1.mga2
+ Revision: 217397
- update to final 0.9.7.0

* Thu Feb 23 2012 julien <julien> 0.9.7-0.bzr3017.mga2
+ Revision: 212684
- update to latest bzr
- clean BR
- replace description with a more meaningful one

* Sun Feb 05 2012 julien <julien> 0.9.7-0.bzr2979.mga2
+ Revision: 204813
- update to prerelease 0.9.7
- switch to launchpad as source
- drop upstreamed patches

* Sun Jan 22 2012 julien <julien> 0.9.5.92.1-5.git.20111101.mga2
+ Revision: 199860
- fix build of KDE decorator with new gcc

* Wed Nov 30 2011 julien <julien> 0.9.5.92.1-4.git.20111101.mga2
+ Revision: 174584
- add a provides on compiz-fusion
- update to latest git (hopefully, less bugs...)

* Sun Nov 27 2011 julien <julien> 0.9.5.92.1-3.mga2
+ Revision: 172893
- merge compiz-fusion
- add suggests to ccsm and plugins
- drop kstylerc.xinit, very old file used with kde3

* Mon Nov 07 2011 mikala <mikala> 0.9.5.92.1-2.mga2
+ Revision: 164613
- Add compiz as requires on -devel (some plugins available in compiz packages are needed to build others plugins)
- remove defattr()

* Sun Nov 06 2011 julien <julien> 0.9.5.92.1-1.mga2
+ Revision: 164364
- limit compilation to 2 jobs to be safe
- clean some warnings
- new version 0.9.5.92.1
- rediff patch 0503 0502 0501
- add patch from fedora for keybinding

* Wed Sep 14 2011 fwang <fwang> 0.8.8-2.mga2
+ Revision: 143178
- drop .la files
+ ahmad <ahmad>
- Replace BR libgnome-window-settings-devel with pkgconfig(gnome-keybindings)

* Sat Jun 25 2011 julien <julien> 0.8.8-1.mga2
+ Revision: 113657
- update to 0.8.8
 - clean up specfile
 - remove old Obsolete
 - drop patchs merged upstream
 - move static libs to devel package
 - add condition to ease backport
+ dmorgan <dmorgan>
- Fix file list
- Rebuild against latest gnome
- fix up the GNOME session stuff so it actually works ( from fedora )
- New version 0.9.4
- New version 0.9.4
  Remove merged patches
- Fix build arches
- Fix file list
+ mikala <mikala>
- Update patch0501 to use mageia-top.png & not mandriva-top.png

* Mon Feb 28 2011 eandry <eandry> 0.8.6-3.mga1
+ Revision: 61777
- drop old conditionnal
- drop buildroot
+ colin <colin>
- imported package compiz

